@@ -5,8 +5,8 @@ function(TX, N, alternative, method, int, delta, alpha, lookupArray) {
   m <- floor(length(TXunique)/2) + 1  #Very slightly faster
   s <- TXunique[m]
   
-  if (method %in% c("asymptotic mcnemar", "asymptotic mcnemar with cc")) {
-    # Many ways to calculate McNemar test, but use z-distribution for one-sided tests
+  if (method %in% c("am", "amcc")) {
+    # Many ways to calculate Asymptotic McNemar test, but use z-distribution for one-sided tests
     pvalue <- ifelse(alternative=="two.sided",2,1)*pnorm(TX[TX[,3] == s, 3][[1]])
     
     #Tbls <- TX[TX[,3] == s, , drop=FALSE][1, 1:2]
@@ -14,7 +14,7 @@ function(TX, N, alternative, method, int, delta, alpha, lookupArray) {
     #mcnemar.test(Tbls, correct=FALSE)$p.value
   } else {
     Tbls <- TX[TX[,3] <= s, 1:2, drop=FALSE]
-    pvalue <- maxPvaluePairedLookup(Tbls, int=int, lookupArray=lookupArray)$pvalue
+    pvalue <- maxPvaluePairedLookup(Tbls, int=int, lookupArray=lookupArray, doublePvalue=FALSE)$pvalue
   }  
   if (pvalue <= alpha){ TX[TX[,3] <= s, 4] <- TRUE
   } else { TX[TX[,3] >= s, 4] <- FALSE }
